From 679fe570a7527eadc1fcddbff619bfb2763f4d98 Mon Sep 17 00:00:00 2001
From: Case Duckworth
Date: Mon, 3 Jan 2022 10:36:32 -0600
Subject: Fix things for Windows Emacs

---
 init.el              | 7 +++++--
 lisp/+emacs.el       | 4 +++-
 lisp/+org-capture.el | 4 +++-
 3 files changed, 11 insertions(+), 4 deletions(-)

diff --git a/init.el b/init.el
index 5d5c02f..dc4bb74 100644
--- a/init.el
+++ b/init.el
@@ -16,7 +16,10 @@
 
 ;;; Code:
 
+(setq debug-on-error t)
+
 (dolist (feature `((early-init . ,(locate-user-emacs-file "early-init"))
+                   acdw
                    private
                    _work))
   (require (or (car-safe feature) feature) (cdr-safe feature) :noerror))
@@ -743,8 +746,8 @@ See also `crux-reopen-as-root-mode'."
   (:+key "C-." #'embark-act
          "M-." #'embark-dwim
          "<f1> B" #'embark-bindings)
-  (:bind-into minibuffer
-    "C-." #'embark-act))
+  (:with-map minibuffer-local-map
+    (:bind "C-." #'embark-act)))
 
 (setup (:straight embark-consult)
   (:load-after consult embark)
diff --git a/lisp/+emacs.el b/lisp/+emacs.el
index d76eee8..2e3d257 100644
--- a/lisp/+emacs.el
+++ b/lisp/+emacs.el
@@ -273,7 +273,9 @@ kill without asking."
 (when (require 'repeat nil :noerror)
   (setq-default repeat-exit-key "g"
 	            repeat-exit-timeout 5)
-  (repeat-mode +1))
+  (when (fboundp 'repeat-mode)
+    ;; `repeat-mode' is defined in repeat.el, which is an older library.
+    (repeat-mode +1)))
 
 (when (require 'savehist nil :noerror)
   (setq-default history-length t
diff --git a/lisp/+org-capture.el b/lisp/+org-capture.el
index 1631bdd..6968657 100644
--- a/lisp/+org-capture.el
+++ b/lisp/+org-capture.el
@@ -4,7 +4,9 @@
 
 (require 'cl-lib)
 ;; We don't require `org-capture' here because I'll have to require this library
-;; to init.el /before/ org-capture is fully needed.
+;; to init.el /before/ org-capture is fully needed.  But I do need to declare
+;; `org-capture-templates'.
+(defvar org-capture-templates nil)
 
 (defun +org-capture--get (key &optional list)
   "Find KEY in LIST, or return nil.
-- 
cgit 1.4.1-21-gabe81